@@ -1,15 +1,11 @@
-/***************************************************************************
- *   Copyright (C) 2017 by Albert Astals Cid <aacid@kde.org>               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2017 Albert Astals Cid <aacid@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "filefactory.h"
 
-#include <QFileInfo>
 #include <QStandardPaths>
 
 bool FileFactory::folderExists(const QString &relativePath)
