@@ -1,12 +1,9 @@
-/***************************************************************************
- *   Copyright (C) 1999-2006 by Éric Bischoff <ebischoff@nerim.net>        *
- *   Copyright (C) 2007 by Albert Astals Cid <aacid@kde.org>               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 1999-2006 Éric Bischoff <ebischoff@nerim.net>
+    SPDX-FileCopyrightText: 2007 Albert Astals Cid <aacid@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 /* Sound factory */
 
@@ -50,9 +47,17 @@ void SoundFactory::playSound(const QString &soundRef) const
   if (soundFile.isEmpty()) return;
 
   if (soundFile.startsWith(':')) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    player->setSource(QUrl("qrc" + soundFile));
+#else
     player->setMedia(QUrl("qrc" + soundFile));
+#endif
   } else {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    player->setSource(QUrl::fromLocalFile(soundFile));
+#else
     player->setMedia(QUrl::fromLocalFile(soundFile));
+#endif
   }
   player->play();
 }
@@ -62,16 +67,16 @@ void SoundFactory::registerLanguages()
 {
   QSet<QString> list;
   const QStringList dirs = FileFactory::locateAll(QStringLiteral("sounds"));
-  Q_FOREACH (const QString &dir, dirs)
+  for (const QString &dir : dirs)
   {
     const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.soundtheme"));
-    Q_FOREACH (const QString &file, fileNames)
+    for (const QString &file :  fileNames)
     {
         list <<dir + '/' + file;
     }
   }
 
-  foreach(const QString &soundTheme, list)
+  for(const QString &soundTheme : std::as_const(list))
   {
     QFile file(soundTheme);
     if (file.open(QIODevice::ReadOnly))
